#  tests for pyee-8.2.2-py38haa95532_0 (this is a generated file);
print('===== testing package: pyee-8.2.2-py38haa95532_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import pyee

import os
import pkg_resources

assert pkg_resources.get_distribution("pyee").version == os.environ["PKG_VERSION"], \
    "package version does not match expected version"
#  --- run_test.py (end) ---

print('===== pyee-8.2.2-py38haa95532_0 OK =====');
